==> james-project-3.7.6-source-release.zip: james-project/server/apps/distributed-pop3-app/src/test/java/org/apache/james/DistributedPOP3ServerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.james;

import org.apache.james.modules.AwsS3BlobStoreExtension;
import org.apache.james.modules.RabbitMQExtension;
import org.apache.james.modules.TestJMAPServerModule;
import org.apache.james.modules.blobstore.BlobStoreConfiguration;
import org.junit.jupiter.api.extension.RegisterExtension;

public class DistributedPOP3ServerTest implements Pop3ServerContract  {
    public static JamesServerBuilder<DistributedPOP3JamesConfiguration> baseExtensionBuilder() {
        return baseExtensionBuilder(new RabbitMQExtension());
    }

    public static JamesServerBuilder<DistributedPOP3JamesConfiguration> baseExtensionBuilder(RabbitMQExtension rabbitMQExtension) {
        return new JamesServerBuilder<DistributedPOP3JamesConfiguration>(tmpDir ->
            DistributedPOP3JamesConfiguration.builder()
                .workingDirectory(tmpDir)
                .configurationFromClasspath()
                .blobStore(BlobStoreConfiguration.builder()
                    .s3()
                    .disableCache()
                    .deduplication()
                    .noCryptoConfig())
                .searchConfiguration(SearchConfiguration.elasticSearch())
                .build())
            .extension(new DockerElasticSearchExtension())
            .extension(new CassandraExtension())
            .extension(rabbitMQExtension)
            .server(configuration -> DistributedPOP3JamesServerMain.createServer(configuration)
                .overrideWith(new TestJMAPServerModule()));
    }

    @RegisterExtension
    static JamesServerExtension jamesServerExtension = baseExtensionBuilder()
        .extension(new AwsS3BlobStoreExtension())
        .lifeCycle(JamesServerExtension.Lifecycle.PER_TEST)
        .overrideServerModule(new POP3ViewProbeModule())
        .build();
}

==> james-project-3.9.0-source-release.zip: james-project/server/apps/distributed-pop3-app/src/test/java/org/apache/james/DistributedPOP3ServerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.james;

import org.apache.james.modules.AwsS3BlobStoreExtension;
import org.apache.james.modules.RabbitMQExtension;
import org.apache.james.modules.TestJMAPServerModule;
import org.apache.james.modules.blobstore.BlobStoreConfiguration;
import org.junit.jupiter.api.extension.RegisterExtension;

public class DistributedPOP3ServerTest implements Pop3ServerContract  {
    public static JamesServerBuilder<DistributedPOP3JamesConfiguration> baseExtensionBuilder() {
        return baseExtensionBuilder(new RabbitMQExtension());
    }

    public static JamesServerBuilder<DistributedPOP3JamesConfiguration> baseExtensionBuilder(RabbitMQExtension rabbitMQExtension) {
        return new JamesServerBuilder<DistributedPOP3JamesConfiguration>(tmpDir ->
            DistributedPOP3JamesConfiguration.builder()
                .workingDirectory(tmpDir)
                .configurationFromClasspath()
                .blobStore(BlobStoreConfiguration.builder()
                    .s3()
                    .disableCache()
                    .deduplication()
                    .noCryptoConfig())
                .searchConfiguration(SearchConfiguration.openSearch())
                .build())
            .extension(new DockerOpenSearchExtension())
            .extension(new CassandraExtension())
            .extension(rabbitMQExtension)
            .server(configuration -> DistributedPOP3JamesServerMain.createServer(configuration)
                .overrideWith(new TestJMAPServerModule()));
    }

    @RegisterExtension
    static JamesServerExtension jamesServerExtension = baseExtensionBuilder()
        .extension(new AwsS3BlobStoreExtension())
        .lifeCycle(JamesServerExtension.Lifecycle.PER_TEST)
        .overrideServerModule(new POP3ViewProbeModule())
        .build();
}
